import { ComponentRef, EventEmitter } from '@angular/core';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/filter';
import { NzbModalResult } from './nzb-modal-result';
import { NzbService } from '../nzb.service';
import { NzbModalStatus } from './nzb-modal-status.enum';
export declare class NzbModal {
    private nzbService;
    /**
     * Passes on the native Bootstrap `show.bs.modal` event
     * @type {EventEmitter<any>}
     */
    onShow: EventEmitter<any>;
    /**
     * Passes on the native Bootstrap `shown.bs.modal` event
     * @type {EventEmitter<any>}
     */
    onShown: EventEmitter<any>;
    /**
     * Passes on the native Bootstrap `hide.bs.modal` event
     * @type {EventEmitter<any>}
     */
    onHide: EventEmitter<any>;
    /**
     * Passes on the native Bootstrap `hidden.bs.modal` event
     * @type {EventEmitter<any>}
     */
    onHidden: EventEmitter<any>;
    /**
     * @private
     * @type {Renderer2}
     */
    private renderer;
    /**
     * @private
     * @type {NzbModalOptions}
     */
    private defaultModalOptions;
    /**
     * @private
     * @type {ComponentFactoryResolver}
     */
    private cfr;
    /**
     * @private
     * @type {Injector}
     */
    private injector;
    /**
     * @private
     * @type {ApplicationRef}
     */
    private appRef;
    /**
     * @private
     * @type {NzbDynamicContentService}
     */
    private contentService;
    /**
     * @private
     * @type {ComponentRef<NzbModalComponent> | null}
     */
    private modalComponentRef;
    /**
     * @private
     * @type {NzbDynamicContent | null}
     */
    private dynamicContent;
    /**
     * @private
     * @type {NzbModalOptions}
     */
    private options;
    /**
     * @private
     * @type {string | null}
     */
    private ariaLabelledById;
    /**
     * The status.
     * @private
     * @type {BehaviorSubject<NzbModalStatus>}
     */
    private status;
    /**
     * The result.
     * @private
     * @type {NzbModalResult | null}
     */
    private result;
    /**
     * Don't use this constructor directly. Use NzbService.createModal instead.
     * @see 	NzbService
     * @param  {NzbService}  nzbService 		[description]
     */
    constructor(nzbService: NzbService);
    /**
     * Shows the modal.
     * @param {any}    content          A component type, a `TemplateRef` or a string.
     * @param {any}    options          Optional. See `NzbModalOptions` for valid options.
     * @param {string} ariaLabelledById Optional. This is used to set the `aria-labelledby` attribute of the top-level modal div. If your modal template has a `.modal-title` element you can safely omit this -- the library will either use the existing id of the `.modal-title` or generate and use a unique id. You should use this parameter if you don't have a `.modal-title` or wish to use a different element.
     */
    show(content: any, options?: any, ariaLabelledById?: string): void;
    /**
     * Use this method to close the modal when the user "sucessfully" completes the modal.
     * The modal's `result.dismissed` will be false and `result.data` will be whatever you pass.
     * @param {any} data The data you want to pass.
     */
    close(data?: any): void;
    /**
     * Use this method to indicate the user has "cancelled out" of the modal.
     * The modal's `result.dismissed` will be true and `result.data` will be null.
     */
    dismiss(): void;
    /**
     * A promise that resolves when the modal has been initialized but not yet shown.
     * @return {Promise<void>} [description]
     */
    initialized(): Promise<void>;
    /**
     * A promise that resolves once when the modal is opened, i.e. after all the Bootstrap animations complete.
     * @return {Promise<void>}
     */
    opened(): Promise<void>;
    /**
     * A promise that resolves once when the modal is hidden, i.e. after all the Bootstrap animations complete.
     * @return {Promise<NzbModalResult>} The result as previously set.
     */
    closed(): Promise<NzbModalResult>;
    /**
     * Use this method in ngOnDestroy to ensure the modal is hidden gracefully
     * when the component that created it is destroyed, e.g. on a route change.
     */
    destroy(): void;
    /**
     * If you've opened the modal with a component type as content,
     * this will return the underlying ComponentRef.
     * @return {ComponentRef}
     */
    getContentComponentRef(): ComponentRef<any> | null;
    /**
     * Get an observable of the modal status
     * @return {Observable<NzbModalStatus>}
     */
    getStatusObservable(): Observable<NzbModalStatus>;
    /**
     * Get an observable of the modal result
     * @return {Observable<NzbModalResult|null>}
     */
    getResultObservable(): Observable<NzbModalResult | null>;
    private _show(content, options?, ariaLabelledById?);
    private onModalComponentInitialized();
    private hide();
    private remove();
    private getContent(content?);
    private initializeOptions(raw);
    private setAriaLabelledBy();
    private setAriaHidden(hidden);
    private initializeClasses();
    private initializeEvents();
    private removeEvents();
}
